"""Aider agent implementation."""

from .generic import GenericAgent


class AiderAgent(GenericAgent):
    """
    Aider agent with pattern-based detection.

    Inherits pattern-based state detection from GenericAgent.
    """
    pass
